(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     91224,       1661]
NotebookOptionsPosition[     88543,       1614]
NotebookOutlinePosition[     89153,       1637]
CellTagsIndexPosition[     89110,       1634]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 10, Section 10.4, Figure 10.11", "Section",ExpressionUUID->"d20ccc21-8775-4cef-ab90-fd5a03fdc6f7"],

Cell[TextData[{
 "The functions defined here are those already used in, for example, ",
 StyleBox["Fig.8.1\[Dash]8.3.nb",
  FontWeight->"Bold"],
 ".\n\nWe start by defining the radius as a function of semi-major axis, \
eccentricity, longitude of pericentre and true anomaly."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"310fd37e-0fed-47aa-914c-3d311a828e23"],

Cell["r[a_,e_,\[CurlyPi]_,f_]:=a(1-e^2)/(1+e Cos[f+\[CurlyPi]]);", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[1]:=",ExpressionUUID->"111466c4-abe8-4896-a335-dc49ea6b0e64"],

Cell[TextData[{
 "Now we define a function ",
 StyleBox["ksolve", "Input"],
 " that solves Kepler's equation to find the eccentric anomaly for a given \
value of the mean anomaly and eccentricity."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1c8d0298-c6a9-472f-a010-f736c390725c"],

Cell["ksolve[ma_,e_]:=FindRoot[ea - e Sin[ea] == ma, {ea,ma}];", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"73585330-7695-47bc-9e98-1f66f0448719"],

Cell[TextData[{
 "The function ",
 StyleBox["position", "Input"],
 " calculates the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " coordinates of an object for a particular value of the mean anomaly."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c1a76d9b-2e27-458e-94ef-a92099002c97"],

Cell["\<\
position[ma_,a_,e_,\[CurlyPi]_]:=
Module[{eca, x, y, c\[CurlyPi], s\[CurlyPi]},
  eca = ea /. ksolve[ma,e];
  x = N[a(Cos[eca]-e)]; 
  y = N[a Sqrt[1-e^2] Sin[eca]];
  c\[CurlyPi] = Cos[\[CurlyPi]];
  s\[CurlyPi] = Sin[\[CurlyPi]];
  {{c\[CurlyPi], s\[CurlyPi]},{-s\[CurlyPi], c\[CurlyPi]}}.{x,y}]\
\>", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[3]:=",ExpressionUUID->"1aaa10ad-ad8d-4f65-aa51-adf8dd4904ea"],

Cell["\<\
Define the resonance (2:1) and the eccentricity (0.1) for the first plot.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6482da08-0c2d-495e-b443-3288a7e07060"],

Cell["p=1/2; e=0.1;", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[4]:=",ExpressionUUID->"2a81ad17-8235-4103-acb4-3cf8fb97ea80"],

Cell["\<\
Generate plots for 11 orbits in the rotating frame with the same \
eccentricity, linearly increasing semi-major axis and linearly decreasing \
(from zero) longitude of pericentre.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1f9c31f9-68bd-41fc-bc35-34078053b38b"],

Cell["\<\
Do[
  \[CurlyPi] = N[-i*Pi/12];
  a = 1.0 + i*0.15;
  rotlist={};
  Do[
    posvec=position[t,a,e,\[CurlyPi]];
    f=N[ArcTan[posvec[[1]],posvec[[2]]]];
    rad=N[Sqrt[posvec[[1]]^2+posvec[[2]]^2]];
    \[Theta]=p*t;
    \[Psi]=\[Theta]-f;
    blip=N[{rad*Cos[\[Psi]],rad*Sin[\[Psi]]}];
    AppendTo[rotlist,blip],
  {t,0,4Pi,Pi/20}];
  plot[i] = 
  ListPlot[rotlist,AspectRatio->Automatic, 
         PlotJoined->True,Axes->None,
         DisplayFunction->Identity],
{i,0,10,1}]\
\>", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[5]:=",ExpressionUUID->"ca9299f1-753e-4c34-8a5e-1ac256ab1352"],

Cell["\<\
Create graphics objects for the planet, its centre and the location of the \
exact resonance.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3175bc53-7f89-43e3-ae46-2a4a6024f3ff"],

Cell["\<\
planet = Graphics[Circle[{0,0},0.4]];
resonance=
 Graphics[{Dashing[{0.02,0.02}],Circle[{0,0},0.8]}];
centre = Graphics[Point[{0,0}]];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[6]:=",ExpressionUUID->"71f1e8aa-d079-4e07-bfa8-e2c3bce31fee"],

Cell[TextData[{
 "Display the orbits, planet and resonance.  Note that for low eccentricity \
the orbits in the rotating frame for the 2:1 resonance (the ",
 StyleBox["m",
  FontSlant->"Italic"],
 " = 2 case) are centred ellipses.  (See Fig.10.11a.)"
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5da490bf-9d79-4c37-ba05-0b111543ee5a"],

Cell[CellGroupData[{

Cell["\<\
Show[planet, resonance, centre,
    Table[plot[i],{i,0,10,1}],
     DisplayFunction->$DisplayFunction,
     AspectRatio->Automatic]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[9]:=",ExpressionUUID->"19218bcb-efc9-4c2d-ad3c-60f9eb8bef70"],

Cell[BoxData[
 GraphicsBox[{CircleBox[{0, 0}, 0.4], 
   {Dashing[{0.02, 0.02}], CircleBox[{0, 0}, 0.8]}, 
   PointBox[{0, 0}], {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJxVlFtIlFEUhUehhyAoEkHQKbswlIlYGihObREqorHSCs1S0hq7eEstp5Ew
JpHKS5OMaY2JpKVpkob6kKjbh9JMzbxjCZrpkNNkM8FUD17Kzvof5sDP/3A4
5+y11rf3priUcLWzTCYL+/et/Pt6V5aFZFhVqboFzxoLVSgUx1WqFs7/WJup
JgvF593KqfJ4x7KChhaV4RulaaqtSaeG2H3NPXterZlODl0OGYof56CXV0z7
8+eo44Iy/a7nJPtoAuyXgr+Sf669M2zvNPu0jRa59JtoPLg7OuvVDM8fM/es
Dp6l0sLDpbplE8/sMBw9b/xCiRWzm7PXznGP1vdG9Mxn2q1XDHfNmTlU9T3Q
fcsUxQ1WJsToLVxo8Jstap6gyH2VL0ac5jmh08MeJB+n4Q3ro5ZDfrCbi2vu
oG6E+jOqtp7xsvK25+vKMk0DlKwuCs94ZOWm2yqt3NhLHRtHXEr+WFm/uOtq
e+Ib0h2Ub9eSjYsjflc23mmla0+XQutTbXxg3il8VU4dLTy2ap7obZzyoHvg
10WD0vhwZdm4XOyztB8pzrMG57PF/XwT9z8T77P0vpeoj6X6XET9/AH1xwh9
PAZ994V+joL+Q8IfPgd/4B/7w78J4S+nw1/4z0b47yvyYSkfb5EfByG/QJEv
v0W+yJ+l/Jfy//PB18FHgeCH08BPteCL9eAL/PGissy54lNTq7QfL/YpD+e1
4jw5Cf44UdxP0vunxfukRH1toj7yR/3eon7aCX1jQh/9hP4SoZ+m4E+q8Id6
4Z+f8I+OwN9Y4S+Vw/8Twn+KQz6jIh9SIL/3Ij/yccyX6h3zp1zwAf6oAfyA
P2JHvsitryOrObK9FfxRoyOfVOPIL6nBN/ijOkf+yQP9kYL6XNE/4I9i0V+S
vmL0XwT0gz86C3860b8B8G8a/Z0Mf83o/3L47435MIl8vDA/9iA/ab50IV85
5k8k8gcfpAYf0vxKAj/gi26BL2n+Cf5eK/8Ca+3CzA==
       
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw11P9P1AUcx/FTmW4QnOXsChtxzm+TARG1kEPfhkc6ls6DjpECOitKoI7h
RSAoXAqVAkHI/CGaE3D4pZ2dCG0EvOKCCSnEF+WrdMchehwed9yBSwivuven
H157/QOPPaVHVDEfLReJRIp/999bpeKzPUs2cg2jxLyhF5uO9TQ3jM5Qa0zR
ysjEISRpQg4oVVay4q8plcKAie7aLb6/TlNelMmUNm/CybnIiqjBKRq41aio
8HoIw73c2xvxiF5TPilWPzDjR2+fq4ovJyn9A82VlpxpBAaeufps6wRt8FHc
OvSHFTlx2ac0eiO1ryqpesVgw5PC6hOLF+/T84/751cP2OEhn+rOaxwk7zsJ
y6IrZ1FgOXI5Y7iPih0h0RW7HLgRHF6x1+cOLc9us37W5YCHK3SjvFxPR89s
VsfKnDAsfPy0sfwGLUhn2y+XOLEiNrxkPv0gjcoenNN2OFG9P+LtF3frANWp
GrXFiYiuMNG+qFaI392eeW/Oid5cq1x/vRN9/WMStdmJihUJAd87emCsPe3b
1O6EpD5LGzZ3F4G6Sy5TkROx/bZE/z+HUPa1+JpluxOl35rXFujuo7M8v7pm
yIFU//Hx828Z8aouwL8hwYHj9Tsza7xM0E39/MIPnbNIzD16vPTuBKzNlUUN
frNwdanSc8omUa9b5r37oB25kgUfw85H0AbuMXouzWDvZr/vMoxmFESO/RIj
tmIuXha++lMLTlb2Kf6etkDr2TZ8wTSNuIxe13yZGW9EN2k9I6yo3SZZqxc9
RHicOGzHsRkcOryvrSVsAk3lPtNyjQ3xv9elfCEzAhdGPXYE23EgOO22QzKC
m1XJuzI1dmw7/F6nPKkf4WL1iQ/r7PALinAlX+9AaV7oYEGrHeu/Gm9e9/5N
rExcJ11zxQ5zSECdLL+KvGrTUpWf2FGcXf1S0OnfSPCHRfZHW9kftOyPEtgf
HOyPJtkfstgf5bA/jLA/GmN/CGJ/VMf+kMr+KIj9YRP7o3z2Bz37IzP7wxr2
R17sD8+xPzrH/nCW/RHYH0Tsjx4/c/tDCvsj6aLbH56yP9qz3+0PI+yPCtkf
tbA/UrI/EvzRAPsjwR+dZ39kYH/ky/5I8Edx7I9K2R+Vsz/qYH+UzP5oPfsj
wR/9xP5Iyf7Ixv5oVbfbH+nYH33O/kjH/ugd9kffsD9aYn+Uxf7oGvujJPZH
oeyPLrE/epP9UQr7oxb2R4I/EvxRPPsjwR8Fsz+SsT96mf2R4I8GCt3+SPBH
ea+7/UHwR9XsD//3b0no3z//18yo
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJwt1P9P1AUcx3EiMEXZOOOL2hkTF8ocMr4sra29WsAwdSCkCEO2RETmQCCy
KZqHhENseDnAAQqsjCYHJCbo7ai9/IbSwo0j5VAE9RAiMeDuwxGOlIr354fX
nv/AY68VKVlxu52dnJxi/9v/rfbbsD3y3QlcefvYaKzRSq/TFTM7V4whI6Y1
65utw3Qk3LnrrR/FjG5xWV/rn1QG1rl4XhvBEt3QTwu6n7PiyMkgv5tDcE+5
Wn7n23Hm5trO5NVZkZSZNrHHw8btq7QbBwYHMFihSfjZ387x+H9CCvb2wnzi
80l4Kjyd9llgqmLGjkvL+oIeKLS8KGCY72147cly3pk3yeD9u35XQlrhrS/P
fDk1ya9v8JJbcjHr/UKubo5z0D9COztGE9fEJ1iLTzp40MXhFd3WwbaOyuXt
TQ4GbIu9tdJs5gOvguGuiw7GadYaNi2wMHub85J1Zx2M33LLGjzvIb0XtuwP
2+egtXaqaFfqYxYZciqNqx00/h06GF5vZZet0ZLeOcnhp9d9q7qf8oJeWVSX
OMmBPM8fo54Ms9/91LmSLoWeJYeOaHpGmL5hfZZbsEKPLeV/fHXxGfOxCt15
dnYajx+25D6n8fYscptsLE0O/KhHO0av9NQDOzom6D5b/dq1hnHe3fdJs7l8
nFOaiJwq/QQvR4Yrvel/8ZBS6VL8vo3LDU3ni+eP8j39mqSQezZWciTlfu4I
1/+qb65PtrOk40J0gGGIZ6JiTCfMduYszYg52mDl7u9c780EKixMrqsx2AY4
qLnsbcpSeDaxR6lb3csnureaQ0oVpsGtIO11MyM++NDUWKawKKlqWrvsBm8m
ZYQey1Z4cOL7H76IrubaK9P+h1cqfPMNy6b6SCPyA3x/cW+wUxMVOhum7cSY
bunjTlc7a2tefvzMtQeBr+b/1hxq4/njOp/0vn7Uij+2ij9oxR9TxR/GxR9f
iT9MiT96iz+cEn/0EH/IFn9U/WGv+OMj8QeH+GOX+MM58UfVHwzijz7iD7Hi
jz7iD6XX5/xB9Yf74XP+oPpDmfiDSfxhkfjDQ/GHjeIPOeIPieIPqj+MiT8U
ij+YxB9Uf+gXf2gWf3gk/qD6g+oPqj9oxB904g/t4g9t4g968QfVHxaKP1jE
H16IP7SIPxwQf3hH/EH1hwrxB9UfisQfKsUfCsUfVH84Kv5gFX9oFH+wij9k
ij+Eiz/kiz+0iz/EiD8EiT9Mz5vzxy/FHz4Vf1T9oV78UfWHFvHHGvX/VH/8
F8xiwys=
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw9lH1MzHEcx1vZjJpyF5VKndyGJeKuwh+fzZIt/wg92Ck5mpFJNlFbM00u
FsnDP6YwrTJdalaTpY+nLOahp1HGypXWarnT3f00zYjP++eP23f77fvweb/e
r53OnLMty9PDwyNp5vd3df++oMmwTJBLVvbLna1TvMaoIr84tDPTwXRnmuzx
I/Q4eyh4vOc7N+vGcop32mg4rf5gZJCT40KbdhlufyJ39c/CwigXN95N9jXl
99J852DiEa2bTUWzlvlXdZBt4MFrz5dubqlZvLk+sJF0by/mJiYpXGTM3ldb
V8dBZcbegHsKX9rfvrt/zwu2JBiGb3xVuL3DUdl0spt7fW5Z10wpnKP1DC7I
7+cPGy/HeI0pfKX6jFeuzyA74nvMHm0KLzj+0Vq6coi1AbEPW/MUPqCPrK0M
G+Gla1f5mhcqHLf9V9e4bZTPa8qd1ko370h5YzaeGOcun1NbXH5ujrbqt1oG
JzjkVdZn/WEXm+YmzLHMc7Ap1ZDU3+zkb5sKNuQHzHCw6a8mj0/ymb2p3hXe
k1yCtQnfJ7AvFefScc8i3BuHd97hXRPmUOcyYM5wzH0IOTTIFYacduQuBQeV
SwE4qdyeg6PK9RE4q9yPoYdw9NKGntTeotGjFr1WoWcFvRvgwQi8aIAnz+CN
ER5dh1daeKZ6p3oYKN/5muyjWDnHT+UeapV7eUjeoRXyLv+QOahe5mL4RyUy
Nw9IDuqTXGpOGjH8y03gQA3ChcCJWoUbgSNlCVcCZzor3An+UYj0QuiJ0qU3
ipAeKUp6pTLpmVKld+oWD2i1eEHB4gmliDeUIR7RqHhFLeIZnRbv6BzW+/hu
x740nIN//++NxTudeBf+EfyjaMypzp2JHL7ItRw51dzl4PAeXPLASeXWB44q
15vgrHLXxEgPS9DLUfQ0jN4i0CP8oxr0PIXe18GDL/CC4ckTeLMeHuF/jfzh
2TS8s8PDPwjpqIE=
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJwt1P9T0wUcx/HdoBlfRK+6EPAUi2gqeBpoRodvlVC8Ir7MS/Kc8qVOksNB
8uUEEY+IUiKsLBJS1uqQikNKyYzRK4jOIlE0UErGl+FGbMj4bOzrL1S8Pz+8
7vUPPO65KlOV+rpUIpGk/Lf/3//uF3mxvpP0tuXGh7I5G7K3nqvUHNBTYkNz
woO1dhga6l2u4HuUnrlSUrXOgTtrXRmql27RlDaxasrtAK1v2vXxaCcl5qxo
euJ9Jz5Js9QYH9ZA1pLfbp12otFYcfNsxTUoliaFvhnkQlqMYfXx2QGkZGJI
HehCX/8iYbRDB11j2VWX2YmbT9WEj/pOYLtFdjqgwYnLOzb1FHuMUPr07ExY
7YTizMkCv69NWLl3qOiregf8zp3xOrxsBvFteasuW+3IvzKn69XMYqli58ir
0Xb4f/6335NBVjyTIsjdGXMw7Ik6MaGyIWf+4mNZZTZU6w/GD1yYw5+mkGTj
O1Y0lb88/VuXHX0twmZlhYBHHi3/7L2fHJj0uV0SmzuL8hOOX26ddyK165uG
5A9mgLDqkrAsFyL21Xbb5dM4Pz88MOLnhmbE0tapnsJm6YsfrTjrhnW94PW9
04gaQ3V/h68Hwz1jL/wecR/H63Snt6Z7cMCxpXFiyzjC31CnjX/qQWV1d+fG
vcPYtf3xuOJLHgQFvzbW/mAQ0blRR461euCJkIWk593Avlfi1/i/64Grsdu8
vOhn9KulSf/EehAS8rRG9WwtNpi3tVb1ufGcTFGiCPyRcpafVMuj3RjuPxoT
WXidwrzrbs8fdqFj7FqXLvAOWQzCwcxSJzqutnhZ/EcoUpu8YckeBwJ1rdkZ
0gnaP3h9ulxiR4z3pYDFNiON/zWkiiu2oT39Ypu010QF8/e0u7UCChL1y0qL
Z0hetKYUX1qgbzlkqLPPUm7hH4W/lpqRX5d/5LtTVhL9QfRHhewPCeyPdOwP
oj8ysD+Y2B95sz+I/uhb9keiP1KyP9rN/iiO/VEq+6Mf2B+J/ugu+yPRH7Wx
P9rP/iiJ/VEo+6NF7I92sD8S/dES9kc+7I+i2B+J/ugQ+6NT7I8G2R81sz/q
ZX+0mP2Rmf3RUfZHWeyPtOyPNrE/Ev2Rmv3R8+yPTOyPatkfif7oGPujLPZH
cvZHb7E/Ev2RO2jBH21kfxQQueCPlOyPBPZHoj9qDl7wR1Hsj/QPLfiD6I/u
sz+Esz+qZ38Q2B9dYH9Yx/4omP1Byf5oG/uDnv3RFfYHFfujMvaHUPZHk+wP
2eyPCtgffMX+VYr9+xctDtOn
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJwt1P1PFAQcx3FkgGXRAgTWLAyaS+52M083xZEfUGYkT3qeHdwNisA5mpOr
SSpmriYlsyDADQOkHOETIWJ6KkXfBDr0wFh4OKELdkfcQ3J5HNwTx50V3/vh
s88/8No7/t1SyZ7goKCgnf/t/5cJ9M+rY8YQfeXxgUKZmxZ63W791Xu4IUg1
DrncZFE33Mh59Xs8XRjVK5V7KKVHt9/k/Jlm87MnTxzzUF6tre31O8PUVCNL
euo9D/mUo6FrD/9Jb54oDg6P85CWMvtrxiZpRFcR+fhbN71wOmJd5Q9mCslJ
FzW7XRQd3iWITbHSFk+5OlHoIvEBrWSg20Y3s83Cws1O2nBK9+RBp50cLWZD
9QYHvW2U2YxH5ihh80SndMUcHTtfr5a/6CTVrbz7VVY7rTnTfz34lItK60W/
KTpnqGxvc8fMpJue+2L1tZdLbPRl1tq63PB5invmnnG96B9yCD8vK4nwUrtJ
t+SvskcUqi9qS53xUlhPl+y7djNJFNJVo+0LZPNVVni1U1S8+8Kg4w0fmYT9
Ks0jA0mah/rjf/FR676zy+2GCerbnzPUEuOn2gLpsk2aUfqxyBp8OMNPSVs3
Hcw4eZ/kEpUzp8BPqxNMFZHpGnrteu788Ww/VZXWDd/Z3kXRimvWlSv8NBQX
o4/SF+PjDxuztT0+evjgowRv2k8Yrc6vDknzkeH3iextaYOYnheINU0L1Do9
eWsgdwSDSzJrQwa8dDtPfD6yQ4eWVOMZ5eA81TiPDxnDDWjTF00NNHuobj1i
E+9OYXjXp7GhKW46ckg6vvQTC8aStzrLLzvJcmH2qEBoxfZL39xMt8yRKMsi
qs+3oVqw6mCjzU5TYRuTlRF25Fyum1iqttHuRKVRcXEWK8VZV1tHp6l3Krkq
4yUHVHdLdiVpTfT1thDj3j1OPKkPK+iuNJA89a3xc+UuyNkfBfxhS9+iP1Kx
PzSyP1rG/uC7vegPdvaHEvaHBvaHoPcX/SHgD33sDw/ZH6LYH0LZHyLYHwL+
sJH9QcX+sI79wcP+EPCHePaHQ+wP3ewPYvaHfewPSvaHKPaHk+wPr7A/BPyh
jf0hjP0hhP1hJ/uDg/3hHfaHOfaHHewPV9gffmV/KGV/6GZ/iGF/ULA/5LM/
rGF/OMr+EPCHkYhFfxTwBzP7oz/YHzrZH/3N/nCR/ZGG/aGP/dE59ofP2B9d
Yn9oYn80wv7wAfujcfYHM/ujTPYHIfujr9gfTOyPpOwPEvZHz7I/qNkfdbA/
NLA/8rI/KNgfFQX6tzzQv38B8zLV0w==
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJxdlFtIVGEQx48uWduFpAuaq65LCxVZhIuhIc7J0kxzcSXBFqnQlNJQFoII
7cEHU+zBtF4q85KX7LZtrqbg5mwbhVBZVKKlYYlYamqaoutRt2LmBPpwOA8f
833z//9/M5qU7IQ0d0EQDH+/f39Lol5Q7i4PSy52TG9PlrCxpmjILLXj7E6z
LXKfhB7HPy9mdHRjpu/4jQ+dc3h3INNUn9qPx34aHycGzeG81Oz9SPMD47qj
d4QkOjE/9cJoQOkoXu0ZMx6InEUvz72WN0cnMNTkCHYpZ/DmQuzaEMtvbNW5
0tX3pzGg6+klzadpHHfP1yv3TKFqm/GarWMGDysQcyomsbpKWx1T4kT9uqz3
Sa5f2LsyYvC1RsL2LxEan7tjuKmpMagtbx7LgrSiT9QIxtyakbobFtAyfs7x
ouc7aqPD+oaeLOJo+S5FYdYAttgHyx4Wu3CFUtFvdPuGVw52JSSrBbtJlZ3u
HtiDq0IjfKwpgl1ds9WWZ/yI6fHeRemlgn3qREl9hu8rvKhrC+81C3ZDtmr/
rFcrtvjnjxhaBPvb+COHzpsawuRzHZ1DGtc/p3qQ7/eg+0F+/wy9D3J/btQf
yP0PU/8g63tA+mAj668k/fCV/bGTP1DL/sWRf+DH/kaRv+DH/k+S/7AsH/Dj
/IIpP7jM+ZZQvrAsf2hmPpKID1At5QfqmC8n8QUTTnNT3TurjfmD03QOzB94
Uj3I9bV0Pxj5/gV6H+T3C6k/KOX+PKl/COf+r5M+kPWpSD9MsX5/8gdkf26T
f2Bg/5g/eMn+biD/oYr9j6N8oILz8af8wK2C8muifGE151tM+Yu5nD/zIW5h
Pk4RP2LgSeInh/gSHcwX8ycSfw5bLp8XMJ/Mn7ie6mW+xTXMN/MnZjH/zB8o
eD403L/E8xPL+u7wfG1m/fL89bE/z3g+77F/0Ty/PN8gz7eW/R/m+a/kfJp5
P6g5Px3vj6Kl+aLE+et5/1Qt5QNlfs7y/ipnvpg/jO2zRhZYO//vvz9pHaob

       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJxd1PtP1XUcx/Hvl1bzxEE2izCZV9rRjhSCqwWW74+jQDSXIQvFHQIPNnBn
ihs4BLnLcfN0Dp6TKCo7Im42MynjuIIa76+HnJc4BEQU5Dkd0gMiR+VwgHM6
F6h4f3/qh9ee/8Bjr5V7DqTtDeE47sN/91/Vfa5eU50Nm/Gi1FgTwF0/f6LZ
+q0DN7wXZpRW+VFb3hTiGxtHvaSkOvltH8an82HDjgkcz4376dH3Xqz95UmJ
7JIbbZUZhW8t8OBxeWJ4V+wM2vsLR7Pk06iT1e0LlntRUZCZ2b3WjR2nT1TY
9T7MXd+/vinChXf950tYXgAPScyhW+2PsfjeWsWrz8yi7HFR58baMSwIyJ01
uXPYt0KblChzoOloTFRWCie0Lti2w9Vlx4mlsY82mDkhJONYnJEfxNTUI7rX
X+GF69aha0pdD2ZvL5YU7eeF4uaacxadgLveWLgtppkXNp1ctD+7KA/dVy4Y
kgVeiJnbGNXc1QG47/A59R1euPx+x+3CO93wW33iD2UdvKB/tvEC5xiAJflD
/ZrzvMB92nNY8qYNDm6ZrLereCH2wZBy9dW/wKFobymT8UKopcW3Wj4CmuXL
WxO6OGH29/6QxZ+NQWmg4rtOBScMGD43fPHQCZGWJ5c+uD6Hyspf71dFTMDu
+tJTl4/OYlJ+ha7zSxdkmJ1cypogGmwr4tMS3JCVfWbnDaMfU6y1rt62KWiQ
O0taR/7GH6UVDQkxM3AgPjz9j1kPTj7HAu1aD7RXDcy9OzKNye5x61dDXnj4
p/dQZaMb1crXXqpb6AOTy9MyvNKFHzWZop5G+2GynEUanjrxbO8aSeOLAZh6
YbHXumkUc/yZZ24NBqAtEGbYkTSMi0rv5+xUBeH5npfN1dwAdqelRmbeDMKy
dVcvjqwy4yrL7vzjtiDkbh67pyr7GqTK8JPT3wShxaSfWrq3F3SqK9FaCEI1
+QPRH6SQPwDyB6fIH9SRP1hH/sBJ/kBN/sBK/kBD/kD0B2ryB0ryB6I/yCN/
cIv8QTX5gyPkDyLIHxwkf9BD/kD0x9rIH4j+2DLyB5vJHzOSP/iY/LET5A9E
f6xPP+8PJskfe4f8oUD+mIn8oeiP1ZI/FP0xt2beHxaQPxZH/vAB+WNS8oei
P8YNzvvDMvLHbpM/XEL+QEH+UEH+gJE/TCd/cJr8YQ75A0b+UPQHoj9UkT/w
kD/sJH8A5A9HyR8cI39oJn+wnfzhDPmDBvKHbvIHe8gfXiN/EEH+MIz8gegP
jbHz/iCa/KGF/GEo+cMb5A+15A/L//d//wBYVb5C
       
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJxd1GFM1HUYB/D/3ZkbvICNrlJzMcsOL4IOZUjs4PkNOqgJOawNiDQgsswt
heWNsEHWhl40DhS408qNA6bEDlnzYJjH8yNQJ2EyEcW4HYdgtzvK0+sOTzju
Ip//q148+775vvt+9mwqO7DrI6kgCPmr919258xWy3s8WKSzRegOLOMvjmX+
3D0vqlUX91hqHuP2JHNH1pAfrebK6d78R6iu7fnGVxbAnJbn2zZ7fdgaPzoQ
HF7CI8er7sx+6sXSzpP3zjmCOPVyii+pwYNW6fW58/0hjDr4wKN5yY3yt7Vn
JjYL3IJ1u+bPzuOdG1ccO8cEHjlZ6R4vsaMua8/96XckvBe3rdM3TuDP+dcM
uVYJPyxfXx7xYAj1v+f36SOlfHamGjdqW6CkO3r3sXQpj/whfuRj02V4pnib
3l8g5TyjOSbz75twIi82VFos5VfadfI/FHbIe/P+XxveknI7HvKuqZmDuELj
h6++KOV4fHGpqs8JNxNKYkudEm6Msgw2WxdA15T1lOakhLP2/ZpTzR646CnY
qkyV8BhXx76vTz+E7C6QK0cEXqj/1b/l/X+gqGogRZUucJd87X6nzA8ZFxIL
JNlhNFxzHEtuXYSjnoU3PnevYHNebiJ7OgB1tz+bGd4bRHuZosdW/Rimjdnj
UwNLuDVcof5kbAkO/ZirarwbwPbrO4x9a4PAvlQ9vDWziMkxpqbluBUIxGtN
v/X6sMS7ZO5PCIG09QWH810vug7vk3XJw5DZNmouN3rQ8Z25bHgqDNFy6aQ3
0Y01I2tkp9IEVv+Bxa+smEfX7rpwWqXAUlXff2EetaHhhKwlo1Fg50Jdg1eV
45hWnKKtaRJY6walLH3sLGYrBm1/rvaDzGTq043AZVfyjf4kgW1SWxTrr96G
S3M/rWszhCF2h/uVetNd0MTFs0BtCBpSC7W1WS7QTTqz9m5cgTPkD94jf3Ce
/EEm+YM08gf95A+2kz/IJX/QQv7gK/IHoj+4Rf7AQv5gC/kD0R+7QP5givwx
BfmDevLHviV/IPpjFeQPRH8smvyh6I/JyR8+S/7YAvlb3fmJP3aE/KHoj82S
PxT9sSHyhxPkj3WQPxT9sdfJH1rJH4sgf6ghf6yI/GEh+WNu8odq8gdG8ocN
5A9Ef6gjf2Ajf2gnf5BE/vAg+YNO8oc55A8SyR8+In9QSv4w2PLEH4j+sIj8
gY38YRT5A9Ef7yR/4CR/XEP+wEj+eDf5A9Eff438gYb8cR/5w0vkj5eTPxwi
f5hA/lD0hwbyh0fJH3b97//9CzVtruc=
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw1lFtIVFEUhuccswi7eJkiowgTHFEjzSlSyr3ppYKMzCwV7WZCCSb2IFkS
pKNTU2lSIokY5ohOF2s0yyjZO2vqoabAFMoSw4YGtcHS1FDTjPWfh8PmHPbZ
e63///4VdDRnb6aq0+kS5p7/a1FkpbB7JoQJa7y56ha7NCn04c2mXv2YsOUv
VZpd0yL1zZpFT3xGxFBGcGz36IwYT1mZHtPuEYNOQ0Fdqk6WbepvdxrdoqHW
mhumV2RbSYhxd+VX8aKuJj6+QZEnvziWtE18EDVroxOfLVOlecWjjq2tT4Vf
UsUpcUSVTY6xt3lbHrPN7/MHhq/MvZ/13msI7mSZFqdnulqVFZ1KyeqpXnbo
dF3kuXJVFhRaDPVWF1t43xHRla3KgNieqEJ1kAXsiivWG1W5x5UV/lk/zKJW
nfHSfVek+0aEocDzix1oDmqbNSkybd2PamvYb9bY7+Nn8FekPTv3YtG2ceZt
vx4WU6qTnSGZviMb/7D+B6HGw6OzoirQc++b9yT7NOppsdhmRPnMO9eOlil2
XN1uH4v7K07QyvBddNM+Vk3/iT46h32kc4UX3cNb6F7RQHXwFKpLoE4+QHWL
9dQHT6K+hD/1yX2pbwEduIV0EemkE68l3QR05E7SVcSQzryMdNd84PXkC4NP
nJFv7CX5yJvIV9ZIPvNS8p2BA+4mLthP4oQlEjfsDnHEwBUDZ+w8ccdKsO7E
90Dsu43/9uGcAZw7jXuGcK8JdYA/3oo6O1C3BX3cRF/zA6lPX/SdBx00XV5D
J003M3QEfzwLOmu6L4YPmi8J8CkavvXAx/3wFfwJ8MfvggPwx7vAiRvcXANH
PeDKDM5ywF0GOLwMLrFPVIJbFzgGf2weOH8I7m3IAfhjychJH3KzATlKQ67Q
p1yO3C1ADi8glweR0+fI7THkuBW5hs4y+RXlHj7IUMwF+CSNmBsOzBHwJ2yY
M1cxd7Q5NIu5BE5EOuaWFXNMm2vanCvE3CvG+g9cYo2C
       
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJwt1H9M1HUYB/Dvfe+kmFEDOkBUFkPFwsvGQXIqPp8l0dQGHCCeUgz5McgW
nhOVpEal2IJc3OaMZuASmleRHSh4HuLzSSl0mTW4TAXNAwVFbuwLZ3A/dlfy
fN/be8//7732xBbtzC4VBUHQ/98nl+UVv75RE8DAXCTMPXepUF8n8NYzyZPv
dU7g4MEoiyFXwS9fSfkkTHMfj3ZPGNdNK/jO3vDgiqcG0X6pL3R+mchb/vrs
m7a8Piy9xpsWt4vc7Pkl9YGmDX7uTX3RMSDypLSYl54u6Ic/Dm7+bk+/yBvV
3Q3D+Xfh/pLxrG0WkS9cmOH6dfUYTOyoLYzbJfKI+rVtPu6ErPjQKhYl8nVl
G00/TktQHnSzxG5W8JHq+dM37C7oDH7B9vVSBe+IvjqlPjADw9aTyaMNAm8p
uOZ5y++GwWfdmeqbAWw9Vnsx/Q0fqAPZf47v9mOOLqtqoMAPo80Jt7e4fBhY
rru+OE5gvia3uT3fi7acptmSgMB2r3zwnOV7N46lr791u1fB5q1sdh9yzGDp
kShHeKXI/HO7PcazZ87XVIYo2WTpmsQj81x4+uSbEekmJUupeF57SJKw56uw
keMBJavTHq/21E6iYZPTVmRQMamw37x+ahy3xWh2JR5TsRkf+N5fNorx2akh
xj4V25qUEdkV68DLxe+sSB5SsdCBRerf+v5GvUZYrb+hYp4Fha8ctl7BqoSg
jzfYVCzs81OvZhY34okQ24dvf6Ri/qGGVbqiXuipiUsxLVexxISfNtevuQ7a
mHd70KJkR+NL4NvXHLDWWzt0NkLJYqU7tuj9Y3DCm+QoMYhsn86ktZ52ghj+
6R1lpYJlDFZrh50SWIIEqbhcYCZlcHS/0wUV9osFW3f44cBVY4Lh9xlYhpFl
aV1eWHJqb15PjQcyVugaO62z0PzBdnvXrA8uTAeldVQ9Btkf0I4S6Mkfayd/
cIv8sfPkD2R/7DD5gwHyx74kfyD7Y+XeOX8o+2Ph5A9lf8xE/nCE/DHZHz4i
f2wB+UPZHwPyh7I/9g/5Qyv5Yz+QP7xL/piZ/KGD/EET+cNI8ge55A/vkT+Q
/XEP+YNu8sf3kD+4R/74M+QPtpM/rhCe5F/oIn/cSf6gg/zxVeQPZH+8kfzB
FvLHH5I/yCd/3E/+YCn545vIH8j+eBL5g0zyx53kD/aRP26sm/MHLeSPN5A/
vED++MvkD2V/vJ78oeyPB5M/bCV/fC/5QxX54znkD9vJH/+C/KGR/GEd+cMY
8ofx5A83kD9sIX94jvwhyP+PdpzC/wA+Dosx
       "]]}}, {{}, {}}}},
  AspectRatio->Automatic,
  DisplayFunction->Identity]], "Output",
 CellChangeTimes->{3.8120137141942883`*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"f3aa3a3a-ae46-464d-8e3e-9191a65a04e8"]
}, Open  ]],

Cell["\<\
Define the resonance (7:6) and the eccentricity (0.02) for the second plot.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f5c941db-23ef-49df-906d-3d9d2044687c"],

Cell["p=6/7; e=0.02;", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[10]:=",ExpressionUUID->"398cf061-61f9-44f5-97d5-a9ef44f8bca3"],

Cell["\<\
Generate plots for 21 orbits in the rotating frame with the same \
eccentricity, linearly increasing semi-major axis and linearly decreasing \
(from zero) longitude of pericentre.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0ace6405-87c3-4fac-a1d5-e96ca2f4cb86"],

Cell["\<\
Do[
  cp = N[-i*Pi/30];
  a = 1.0 + i*0.075;
  rotlist={};
  Do[
    posvec=position[t,a,e,cp];
    f=N[ArcTan[posvec[[1]],posvec[[2]]]];
    rad=N[Sqrt[posvec[[1]]^2+posvec[[2]]^2]];
    th=p*t;
    psi=th-f;
    blip=N[{rad*Cos[psi],rad*Sin[psi]}];
    AppendTo[rotlist,blip],
  {t,0,14Pi,Pi/10}];
  plot[i] = 
  ListPlot[rotlist,AspectRatio->Automatic, 
         PlotJoined->True,Axes->None,
         DisplayFunction->Identity],
{i,0,20,1}]\
\>", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[11]:=",ExpressionUUID->"eefc483c-40c5-44ab-bd3d-34e51f0c339a"],

Cell[TextData[{
 "Display the orbits, planet and resonance.  Note that for low eccentricity \
the orbits in the rotating frame for the 7:6 resonance (the ",
 StyleBox["m",
  FontSlant->"Italic"],
 " = 7 case) produce seven-lobed shapes.  (See Fig.10.11b.)"
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0caea2b1-7868-47b0-b2dc-691df992d107"],

Cell[CellGroupData[{

Cell["\<\
Show[planet, resonance, centre,
 Table[plot[i],{i,0,20,1}],
     DisplayFunction->$DisplayFunction,
     AspectRatio->Automatic]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[12]:=",ExpressionUUID->"90147afb-0ea1-487d-9c9c-b3391eb67121"],

Cell[BoxData[
 GraphicsBox[{CircleBox[{0, 0}, 0.4], 
   {Dashing[{0.02, 0.02}], CircleBox[{0, 0}, 0.8]}, 
   PointBox[{0, 0}], {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxVlntYjHkUx0Mo1ZLLulZG7cqk3IdsHLmsRmVVSC65tF2EFVJJugzlti5F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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtVnk0FPofHbQJhUoRRaHSI0vKFH0q8VRani1JWcrL8iolJJIWKW0/il5I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       
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtlnk8lYkexi1NstwwUlOJaCJrlDQ0/KQmS6WUqbG1GZKlZRzZSqVmxpJT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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtVms01HsbTaWkOkhqhU6U9KIkSip5RIjKrbucSkiqNyGXTiKkUp15iyQq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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt1vk71IsXB3At11UU0aVS2WLStd5bSOlEpWjTN1KRrWxZynpTmsoSbaSy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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtlmk41AsbxpWO0KZSUtI7KZXSgjaZniRxVLZO2+F1IkzlrUyiokElRZa0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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtlmk0lQsfxaXEW6hIJRIqJ4qMdXHdf4YbUY50NSiE5BjSdC8JiUpSZi9v
0aCiTFHdBhr+nOocUiFDHHIcHLMzPs9zkobbu9b9sNdev7X2/rC/bb2AQ55B
8nJycqk/9X/PzOqra94vgcISfQt6zRhq73S2JQrEYC77PPZb2wT2x648vb9V
BF+2Xyvt5QjQM2+vQF5ZBMIT69u8AkTYc9EkcDhbAHq3bwUv+l2MD5L8Wn11
JoFnesdlhboEHd49HYh6Mg5XcnzcdBslGKi3v8t43xi8lNAqGsOlePuJy1jh
/FE4GmjW0vlZimaXr6oUModBM4uu/eowgRvVjW7vOzgE/iH719/oIPBbt/PQ
bkU+bJbNNRtbS6LXNG103bkB2LfJaqFNJInuCYdrMwd5cPOv8f8ufkhi3sN3
RiqafVBtu97m/jiJGeGqL9Pte+DFoYGjlVoUGqdcn15FfYRlnaTm3E0Urvkj
0SHNqxWOp4Q4a4RRGImUpnvXW0iw2iqfmUIhq/1+aNkVJjQzdRcKblJI3HLL
1vasAvuMoyvSHlHoqllPaB/JwsOhcoo/6ii0v2pT2q5fjeHnrEIWsSisqsJt
dw+x0HqKz+Uzf/YV44UDdU24u1ufnfqEwtTU4HqdDW14o/vHrBm3Kdy40mvy
vWUnHqrjrGlKpdDW1F6zursbt5BKvyqEU2igwlDQs+RiOvdQ6ZqNFCo633Fq
XcXDpeoMIz8lCjczJiR9l/rx2MIDc2KZJCoVhY/MkhvE4HnhAZ7hJC7ISHQ2
DuBjaXDDFGcmiV+uBWrFNAyh5/WKtYxzBIaWMy187UZQ5kg8aSGlyNzVdLKZ
OYoHFrDaC9yleL/0TWf9nnGM7O0y0s+SYIJWjcX32ZN48UdGXFWdGOU2V5iq
1gow6lzI4yKuCNk+OfcUNoqQuWkGf7BXiCe5qodNl4vRZV+TEzE2iXQDc6bo
sxgV78cvTJ0cx9N/5tsO1Uuwal5xpJ54FI9wns92uyDFHVfd5u/7MYw6rIhk
YzsCGd13StV0h1BtQ9jtUz0EnsrXoFnuGkRvhYdPVRkkqsfrRu8v6UeVnhEj
Xy6J84IKdRoW8LD4xpButgOFueeT/ixawkUH5bDQ7VkUxhbb7C3W78EaYulk
WROFdoZqMbkmXXg+RTODmKZQPs2fVUXrQL+WVbzKJTLcoNfr4jf1AdXPqSQf
oMmwPMzaY5d+E7qOTQYlGv7kKANbWh0bL919dc1UV4YdM/xZB08gbmsN3bxd
WYZND76ePuZSjiXraSnnBRSaBmcEcMszIcOYZ0VnU3hXveRMr9wT8OR/n1iT
R+FfrxZXptBY8Fb422qeL4Vtp4JmLbVrBqdWE2nicgq5H3Tq3fzbQTuFtTic
Q6LFu13LbgVx4EjOyI65mSSeIXmPHc25cMSSsM51IvG9lvb75RweRFbOffqY
JDBGP0wcIxwAfrtc4LZbBJo9YD117+BDrmRdvw+dwDl7i3gz0odBkWcYNEVI
0eEuL4/UHoXJK68fpmRJcWnoti/U2THIogRqM1dJsdehcXduyzh0KpoXG5ZI
UL3cVyFYaRLOXCzfP6olQdsfF+mmFgKg8UdC80+IURhFi9T0FkKI1g01t5ci
NP9lvbfQXgQaC53b+KNC/F9p9L1MjggSV1/mBCwXoMec6PyvUWLYKOdqPmA4
gfQ32es4mhK4bHNB+bvqGGZTDivTXkgg6IaWhrRjGCPIEElMoBT2Tf1dbX2R
j1WtNeURCgRUYFx6pc0Aeud7WCoXEnBr+yd6pKAPC58/qLG2IOHbPKJwV9An
/LxAEuxTTQLV0HL6iG4Xzuq29Y40o8DFyDa2VrMdUwWFJ9QuU0D1xFid8WrB
bo7aWnMJBa5xmw4sLmzEojcHNIysZcBa1j91b8ZrnOfK9U6NkEH6bufQmD3P
8WPXqz79LBm0O2jkFH2twtiHVe79N2VQTb0KCXfKQh92sb70J0PnGuO86Ouw
/biqasnP/NwUA0lCzUMIyP46FXNYBvRLbaHtakyI87T58c1OBrmGdMazDw1w
PsOsp22agoizqrZhC1pgOjki+XkpBSf/buicjm2HaINouOpGQf1jS0VVXQ58
LTgVXsQlIeujXo/xSC8cf/mmOoxBwnfaSNgKLg+owPsvlEYIYO84w0p2GgTb
dzMHlfwJKOiIa+zOGwKPOZmVNh1SyJUyS7Tfj8DBz/SSna5SyHFM3lPQOwYf
nhySz0cJbHI7lRz/cgIMhfT1fhsksNXk29OBaAF4tLq5dd0TA+fwtp5PciKY
/d7i2XdjMWTG872f3xWBY+SSqrwSEWyJz3FsdhFDTGtmQKSeCK7Jd7gu+SAG
kxkeSRkrhOD67bWisrsEPGqvfBidmIRFSoGBjrUSKBu+vkA+bwLivWfX6a6V
wnzhW7VPS8fBycHEOi5HCrP9JiijY6Pgq3+Q4T8thbwNunX8gmEIThJt7fi5
k635Ub41jw9bJPaCTjYBp920XvQcGAA9edesyLUkxPo4vTCez4O5Dbxg1TQS
cnrikwjrT7ByXMeydIwEPzK7kW3WCZZRIZ47N1KQmJQoluq1gtLY/IOMVAps
RKP29ZvfgmTnMpXMZgqSOHYjxkVM4PLH6zhKMlDnr5z96vN9KCurVEiwkoEF
LezCY9U4YF1JXcz2koE7mKxbaV6OHQyTqE6GDKyx5qpT0zMsFxQ8enZQBhWp
xuJ029coi3x91zdQBmpX6jWguBE3B++wLHSRgaLd81j2UDP6qoB/tLYMnLZ6
GjROtuJ2e4tOxV4KJjqeRXt968CEX5xrKy5SsEfVm31vNQdTyxIW6aymYEel
z2hw/Cf8j4PGQEQVCWkXdma9PduHtZJT50wMSHiqyE4OYvSjkL6w/mQKAVX5
f6iUBA3i78G0ODOuFB4ZS391PD6EX0709XQbSMHuzFqb8bwRvPTvf7nw73/5
B4F1zMk=
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtlnk0lA0bxpWtqLcUKktlLKVN0jJS3aWyVBSFtCtF0pu0ECFJkibv935l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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtlns41AkXx4esbUMujeXdtURbkgoR07s42VVKqzSFctnyFhVJ5Voil3Iv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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtlmk81IkfgBGp3OTeVdrQTiHZbGr1rXWGchTTNqnNRqQaEVK0JOUoVrm2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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtlmk01YkfxknITiipcdMmRNMyjYRvU6So66+aVLY2XVlHCi2DSi6pxI1I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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtVmk0lQsblbGEJl+nQaQSJWlAPtNjCF3NEslNaDBVMlwJt1xDhiZJEk1K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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtlmk41QkbxiWNRIzKMIVKWYqpIZq8leekbGlBNVKMbSRKJC28Y5TSQtsJ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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtlnk01Qkbx+nNFKqXMG+2kpmSLbKVTB5qDGLebtdMNFRKZJdCUtIkxpIo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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtlvk/1Ikfxz+OFpsUykqpJeRIiLTa6v2ZslKJaKVh25CjaJNaHbRiVbMd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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1lmlQU2cUhm8QC9KItLSog3QEkYI1FESrVuDcwda6MCqg0roghKUqBrCo
w+pAQRxRiIhabBWtqBVQELCVunAuIiiKYFxwY1GwKAKaQFgTkraczx+Z/Lhz
l++c8z7PsZaGewcbcByX9t/v//8yr+6nO/1PuDqslV/rPcMJf4zNHKU6X4b2
p23A5zQntGi7Zn0UUIsRTsnilGxOGLZb3jqwoR7HmN4+X5vBCRIFnhfNbcRZ
RaouWQInZOwIe95Y9QIvaWO8t23ihIVJRj6RhS9x5ZYBj+xlnBBhWuQn9X2F
beMt5rt8yQlKw9HSlOvtGN/ws5GZMSdM/itEk8V1Yqpj5tzNRXoU8nd1WU54
ize+fZfb7K7Hj9dHz0sXKxEGFs9RX9Bh+pGQsUpjFaZ9kGnvZ6bD8sQMZaVR
N4bnheWsWTqM6jWxH4aZ9qCTvecq7WYtxoTsr0+erMbm38uPSEM1KFlTySdA
Lw5FOV/SLxrCoFAD2c5Nffgm1Dv7pskgRlZfyUrJ7sdMz5Pzfyjqx4JWWWx+
/QDGl7rN7PXoQ1lU/LVe8RDaagy2eFWp8UXd7KMG8zTYONUrynJ+D27/NflI
+WotLrjdEeNRrsISZ5itCxlGi2z74EkLlfhIkZ2bt0aHy17VJ0263IXV/7RO
UM7SY8Ifublo0oHByXMeW6j1OHg5vDM/8TWKpUMnChZzwviMXw99bdWGalf5
87a9nCBfXx2me9iKpxMfOY8t54QtO8IlOcdfYIHiyvayV5wwRpU9zrWpCVcG
5ly6JRIJ28aVTbMMeopOilMnrc1EgvUMl/2rLzxEhzeTay6bi4SEgAr7vSV3
0fzGovSksSJherF2o3VWFX58b2W0h44TdhvNXqYo/xO/z/sx5HAbJ/Q3uKwe
9t0L+SUnu4xucMLWFYGGg7+UweZ83Z5RxzmhKmkDF5l2B4LnV/tP+IkTQlee
keTZ14PXadVSI3dOyG+pvOd7phHMvTuM7xtyQrltpdZL3gJ7np1wDZTrMXxB
3VDIjDYYb9uZVDFOj7Wu1jutz7aDV35h4bO9Oiye+pGd4m0nyF2snJ8Z6fCT
m067lqreweqmlOZzCcOIyfapeb4qMDBdXqjo1aKiyPZwwYFuuOP4tjk4SIsr
csrcxcU9UG6mKg29qcH4uLjm+hI1KPWOhxysNOjqFxIRdKwXlsTZlBxbN4T3
plSWVsb0weMf1w9zOwfxt/6MLhfPftjn9OSNnXwAsXu6T8zEAWgffeq+Jqof
F6wbmhbyagAep9h3POH7EFJrZUv+HoSOiLQNDW1qTCs93FS4bwh66lTrJ8l6
sDfG/KBEpoHupPRDNY9UeDDIdlSWpxa8glNv2UiUeDvV5EHAF8Pg/WLMRW17
J55oeu7uPFoH36xK2Zce0Y7WA9qaxIc6MG2sSrfj2lDqr++TZOnBISVuQ2Bu
C54PzXRvseX436+mX7PpaULD2gd/3o3keFlL6etT3Y/xcJT4asdFjndyrNh4
y/c+bqldODVRyfFuG6OjbFxrEPIDq8VWIl7aYG7WKbuG2+8e6XFwE/EXJD1Z
4i+LUfEy0Sp9uYifOergwpwprVce5US4mfiK+LOOI9ehjl1vpPthG7v/Ij0f
3NnzX0tG3g9b2fvz6Psgi32fF30/GLHv96DzQQE7342GkfNDGDs/UH3AltVH
QvWDs6x+S6m+cIfVt4LqD0Ws/sPUH+hi/XlN/QM5618r9Rdmsf7WUv/Bn/U/
ieYDath8tND8gJzNTwDNF/zN5usdzR+4sfm7TfMJEWw+r9P8QiCbXxOab6hg
872Y5h+a2fzvoHyAD8tHMOUH/Fh+TChf8Kkb5esA5Q++Yvn7lPLJn2H5ZPnl
L7P8BlC+eT3L9ybKPx+aTPk/R3zgj3oTHxg/eMta4ocZ8YWPNSa+WBB/eG0h
8ceO+MSLpMSn2cQv/roT8WsF8Y0vZnwrJv7xsUriXx7xkZ/G+PiO+MnXMX4a
El/57Yyv/sRfsLhC/K0jPsM6xucW4jfYMH4/J75D9VHi+zriP8gY/1+SH+AJ
80M4+QOsmT+KyC8Qw/ySSf6BSOafieQnmL6Z/GRJ/oIPoslfy8lvoGF+s1s7
4j8QM/81kx9hLfPjVfInRDJ/Cn4jfoVNzK8V5F+oYv71IT/DDubnA+RvSGH+
riS/QxPz+9OfR/wPfsz/W2k/gKtsPyim/QFmsP3hs89H9gt4v18ItH/A+/3j
u09G9hOwZftJk/rz3YLUwO39/vIvPX6r0g==
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtVnk4lQkffd8yZMlWSVrIZJjbYgzaNH6vYmqs3UshI1kjW6aUlKRbKpKJ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       
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtlnk4lXkfxp/fo1RSyZI9NFOvUelMKIP6PVGokxaVpbQ3SEKLmTGqSYVk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       
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtVnk41O0C/f1+I7TYvkqfPiRFC0kqS4v3VZHLtRQVmWS5lSzRoqyVSpIW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       
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtlms41Osaxv8HKko6rpmUZKJSm6yoULxv2hVZHXRWklXkkLOU2klOUWg1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       
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtlnk0lWsbxt/9vrtTpiTtInVERUnkGJroeYSor8gQCZ0IUUpRIo3IkCbz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       "]]}}, {{}, {}}}},
  AspectRatio->Automatic,
  DisplayFunction->Identity]], "Output",
 CellChangeTimes->{3.8120137167573643`*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"4d197edd-29c0-41a2-ab4a-3fadb5ef3dac"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{915, 482},
WindowMargins->{{27, Automatic}, {372, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"0fad1a2e-907f-497b-bb63-e544f54fb865"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 112, 0, 67, "Section",ExpressionUUID->"d20ccc21-8775-4cef-ab90-fd5a03fdc6f7"],
Cell[673, 22, 398, 9, 95, "Text",ExpressionUUID->"310fd37e-0fed-47aa-914c-3d311a828e23"],
Cell[1074, 33, 211, 3, 30, "Input",ExpressionUUID->"111466c4-abe8-4896-a335-dc49ea6b0e64"],
Cell[1288, 38, 319, 8, 76, "Text",ExpressionUUID->"1c8d0298-c6a9-472f-a010-f736c390725c"],
Cell[1610, 48, 209, 3, 30, "Input",ExpressionUUID->"73585330-7695-47bc-9e98-1f66f0448719"],
Cell[1822, 53, 369, 13, 53, "Text",ExpressionUUID->"c1a76d9b-2e27-458e-94ef-a92099002c97"],
Cell[2194, 68, 458, 12, 156, "Input",ExpressionUUID->"1aaa10ad-ad8d-4f65-aa51-adf8dd4904ea"],
Cell[2655, 82, 207, 5, 53, "Text",ExpressionUUID->"6482da08-0c2d-495e-b443-3288a7e07060"],
Cell[2865, 89, 140, 2, 30, "Input",ExpressionUUID->"2a81ad17-8235-4103-acb4-3cf8fb97ea80"],
Cell[3008, 93, 313, 7, 76, "Text",ExpressionUUID->"1f9c31f9-68bd-41fc-bc35-34078053b38b"],
Cell[3324, 102, 639, 22, 336, "Input",ExpressionUUID->"ca9299f1-753e-4c34-8a5e-1ac256ab1352"],
Cell[3966, 126, 227, 6, 53, "Text",ExpressionUUID->"3175bc53-7f89-43e3-ae46-2a4a6024f3ff"],
Cell[4196, 134, 269, 7, 84, "Input",ExpressionUUID->"71f1e8aa-d079-4e07-bfa8-e2c3bce31fee"],
Cell[4468, 143, 372, 9, 76, "Text",ExpressionUUID->"5da490bf-9d79-4c37-ba05-0b111543ee5a"],
Cell[CellGroupData[{
Cell[4865, 156, 266, 7, 84, "Input",ExpressionUUID->"19218bcb-efc9-4c2d-ad3c-60f9eb8bef70"],
Cell[5134, 165, 15556, 277, 414, "Output",ExpressionUUID->"f3aa3a3a-ae46-464d-8e3e-9191a65a04e8"]
}, Open  ]],
Cell[20705, 445, 209, 5, 53, "Text",ExpressionUUID->"f5c941db-23ef-49df-906d-3d9d2044687c"],
Cell[20917, 452, 142, 2, 30, "Input",ExpressionUUID->"398cf061-61f9-44f5-97d5-a9ef44f8bca3"],
Cell[21062, 456, 313, 7, 76, "Text",ExpressionUUID->"0ace6405-87c3-4fac-a1d5-e96ca2f4cb86"],
Cell[21378, 465, 605, 22, 336, "Input",ExpressionUUID->"eefc483c-40c5-44ab-bd3d-34e51f0c339a"],
Cell[21986, 489, 378, 9, 76, "Text",ExpressionUUID->"0caea2b1-7868-47b0-b2dc-691df992d107"],
Cell[CellGroupData[{
Cell[22389, 502, 264, 7, 84, "Input",ExpressionUUID->"90147afb-0ea1-487d-9c9c-b3391eb67121"],
Cell[22656, 511, 65871, 1100, 399, "Output",ExpressionUUID->"4d197edd-29c0-41a2-ab4a-3fadb5ef3dac"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

